# Citing

To cite PySR or SymbolicRegression.jl, please use the following BibTeX entry:

```bibtex
@misc{cranmerInterpretableMachineLearning2023,
    title = {Interpretable {Machine} {Learning} for {Science} with {PySR} and {SymbolicRegression}.jl},
    url = {http://arxiv.org/abs/2305.01582},
    doi = {10.48550/arXiv.2305.01582},
    urldate = {2023-07-17},
    publisher = {arXiv},
    author = {Cranmer, Miles},
    month = may,
    year = {2023},
    note = {arXiv:2305.01582 [astro-ph, physics:physics]},
    keywords = {Astrophysics - Instrumentation and Methods for Astrophysics, Computer Science - Machine Learning, Computer Science - Neural and Evolutionary Computing, Computer Science - Symbolic Computation, Physics - Data Analysis, Statistics and Probability},
}
```

To cite symbolic distillation of neural networks, the following BibTeX entry can be used:

```bibtex
@article{cranmerDiscovering2020,
    title={Discovering Symbolic Models from Deep Learning with Inductive Biases},
    author={Miles Cranmer and Alvaro Sanchez-Gonzalez and Peter Battaglia and Rui Xu and Kyle Cranmer and David Spergel and Shirley Ho},
    journal={NeurIPS 2020},
    year={2020},
    eprint={2006.11287},
    archivePrefix={arXiv},
    primaryClass={cs.LG}
}
```
